This is the mechanism by which install.packages determines which packages
should be installed from where. With this override, we can indicate arbitrary
repos, Package, File for each individual package.
availablePackagesOverride(
toInstall,
repos,
purge,
type = getOption("pkgType"),
verbose = getOption("Require.verbose")
)A pkgDT object
The remote repository (e.g., a CRAN mirror), passed to either
install.packages, install_github or installVersions.
When options(Require.usePak = TRUE): repos is added to pak's repository
list via options(repos). However, pak always includes CRAN and Bioconductor as
built-in defaults regardless of this setting -- repos can only add sources,
it cannot prevent pak from also searching CRAN. This differs from the default
(usePak = FALSE) behaviour where repos strictly controls which repositories
are used. Use pak::cache_clean() to clear pak's download cache if needed.
Logical. Should all caches be purged? Default is
getOption("Require.purge", FALSE). There is a lot of internal caching of
results throughout the Require package. These help with speed and reduce
calls to internet sources. However, sometimes these caches must be purged.
The cached values are renewed when found to be too old, with the age limit.
This maximum age can be set in seconds with the environment variable
R_AVAILABLE_PACKAGES_CACHE_CONTROL_MAX_AGE, or if unset, defaults to 3600
(one hour -- see utils::available.packages).
Internally, there are calls to available.packages.
Numeric or logical indicating how verbose should the function
be. If -1 or -2, then as little verbosity as possible. If 0 or FALSE,
then minimal outputs; if 1 or TRUE, more outputs; 2 even more. NOTE: in
Require function, when verbose >= 2, also returns details as if
returnDetails = TRUE (for backwards compatibility).